# remirepo spec file for php-lz4
#
# SPDX-FileCopyrightText:  Copyright 2016-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package        php-lz4
%else
%global pkg_name    %{name}
%endif

%bcond_without tests
# To build with PHP 5.x use --without apcu
%bcond_without apcu

%if 0%{?fedora} >= 34 || 0%{?rhel} >= 9
%bcond_without liblz4
%else
%bcond_with    liblz4
%endif

%global gh_commit   83c6409ae7a98c91ce7419e9028f49ce6bf94863
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    kjdev
%global gh_project  php-ext-lz4
%global pecl_name   lz4
%global pie_vend    kjdev
%global pie_proj    lz4
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini
%global sources     %{gh_project}-%{gh_commit}
%global _configure  ../%{sources}/configure

Summary:       LZ4 Extension for PHP
Name:          %{?scl_prefix}php-lz4
Version:       0.5.0
Release:       1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:       MIT
Group:         Development/Languages
URL:           https://github.com/%{gh_owner}/%{gh_project}
Source0:       %{pkg_name}-%{version}-%{gh_short}.tgz
# retrieve a recursive git snapshot with submodule
Source1:       makesrc.sh

BuildRequires: %{?dtsprefix}gcc
%if %{with apcu}
BuildRequires: %{?scl_prefix}php-devel >= 5.6
BuildRequires: %{?scl_prefix}php-pecl-apcu-devel
%else
BuildRequires: %{?scl_prefix}php-devel
%endif
%if %{with liblz4}
BuildRequires: lz4-devel >= 1.9
%else
Provides:      bundled(lz4) = 1.10.0
%endif

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
Provides:      %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj}) = %{version}
Provides:      %{?scl_prefix}php-%{pie_vend}-%{pie_proj}      = %{version}


%description
This extension allows LZ4, a compression/decompression library.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc

cd %{sources}
%if %{with liblz4}
# Use the system library
rm -r lz4
%endif

# Sanity check, really often broken
extver=$(sed -n '/#define LZ4_EXT_VERSION/{s/.* "//;s/".*$//;p}' php_lz4.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
    --with-php-config=%{__phpconfig} \
%if %{with liblz4}
    --with-lz4-includedir=/usr \
%endif
    --with-libdir=%{_lib} \
    --enable-lz4

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --with-php-config=%{__ztsphpconfig} \
%if %{with liblz4}
    --with-lz4-includedir=/usr \
%endif
    --with-libdir=%{_lib} \
    --enable-lz4

%make_build
%endif


%install
%{?dtsenable}

# Install the NTS stuff
%make_install -C NTS
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
# Install the ZTS stuff
%make_install -C ZTS
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif



%check
cd %{sources}
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if "%{php_version}" > "7.0"
: Check that apcu is aware of lz4 serializer
%{__php} --no-php-ini \
    --define extension=apcu.so \
    --define apc.enabled=1 \
    --define apc.enable_cli=1 \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --ri apcu | grep '%{pecl_name}'
%endif

%if %{with tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff || : ignore
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%files
%license %{sources}/LICENSE
%doc %{sources}/CREDITS
%doc %{sources}/README.md

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Jul 15 2025 Remi Collet <remi@remirepo.net> - 0.5.0-1
- update to 0.5.0
- re-license spec file to CECILL-2.1

* Fri Nov  8 2024 Remi Collet <remi@remirepo.net> - 0.4.4-1
- update to 0.4.4 (no change)
- update bundled libliz4 to 0.10.0

* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 0.4.3-2
- build out of sources tree

* Mon Jan 25 2021 Remi Collet <remi@remirepo.net> - 0.4.3-1
- update to 0.4.3

* Fri Jan 15 2021 Remi Collet <remi@remirepo.net> - 0.4.2-1
- update to 0.4.2

* Fri Dec 18 2020 Remi Collet <remi@remirepo.net> - 0.4.1-1
- update to 0.4.1 with bundled liblz4 version 1.9.3

* Fri Oct  9 2020 Remi Collet <remi@remirepo.net> - 0.4.0-1
- update to 0.4.0
- enable apcu serializer with PHP 7+

* Fri Oct  2 2020 Remi Collet <remi@remirepo.net> - 0.3.7-1
- update to 0.3.7
- drop patch merged upstream

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 0.3.6-4
- rebuild for PHP 8.0.0RC1

* Tue Sep 22 2020 Remi Collet <remi@remirepo.net> - 0.3.6-3
- add patches for PHP 8 from upstream and from
  https://github.com/kjdev/php-ext-lz4/pull/26

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.3.6-2
- rebuild for 7.4.0RC1

* Tue Aug 27 2019 Remi Collet <remi@remirepo.net> - 0.3.6-1
- update to 0.3.6 with bundled liblz4 version 1.9.2

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.3.4-3
- rebuild for 7.3.0beta2 new ABI

* Tue Jul 17 2018 Remi Collet <remi@remirepo.net> - 0.3.4-2
- rebuld for 7.3.0alpha4 new ABI

* Mon Apr  9 2018 Remi Collet <remi@remirepo.net> - 0.3.4-1
- update to 0.3.4 with bundled liblz4 version 1.8.1.2

* Mon Aug 21 2017 Remi Collet <remi@remirepo.net> - 0.3.3-1
- update to 0.3.3 with bundled liblz4 version 1.8.0

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.3.2-2
- rebuild for PHP 7.2.0beta1 new API

* Fri Jan  6 2017 Remi Collet <remi@fedoraproject.org> - 0.3.2-1
- update to 0.3.2

* Thu Jan  5 2017 Remi Collet <remi@fedoraproject.org> - 0.3.1-2
- test build for https://github.com/kjdev/php-ext-lz4/pull/18

* Thu Jan  5 2017 Remi Collet <remi@fedoraproject.org> - 0.3.1-1
- update to 0.3.1

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 0.3.0-2
- rebuild with PHP 7.1.0 GA

* Thu Nov 17 2016 Remi Collet <remi@fedoraproject.org> - 0.3.0-1
- update to 0.3.0

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 0.2.7-2
- rebuild for PHP 7.1 new API version

* Thu Sep  8 2016 Remi Collet <remi@fedoraproject.org> - 0.2.7-1
- update to 0.2.7 (no change)
- open https://github.com/kjdev/php-ext-lz4/pull/13

* Wed Sep  7 2016 Remi Collet <remi@fedoraproject.org> - 0.2.5-1
- new package, version 0.2.5
- open https://github.com/kjdev/php-ext-lz4/pull/11
- open https://github.com/kjdev/php-ext-lz4/pull/12

